package core.entities.timemanager;

import javax.persistence.*;
import java.time.LocalDateTime;
import java.util.Objects;

@Entity
@Inheritance(strategy = InheritanceType.SINGLE_TABLE)
@DiscriminatorColumn(name="scheduleType",
        discriminatorType = DiscriminatorType.INTEGER)
public abstract class AbstractSchedule {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private long scheduleID;

    @ManyToOne
    @JoinColumn(referencedColumnName = "taskID", name = "task")
    private Task task;

    private LocalDateTime startTime;
    private LocalDateTime stopTime;

    public AbstractSchedule() {
    }

    public AbstractSchedule(Task task, LocalDateTime startTime, LocalDateTime stopTime) {
        this.task = task;
        this.startTime = startTime;
        this.stopTime = stopTime;
    }

    public long getScheduleID() {
        return scheduleID;
    }

    public void setScheduleID(long scheduleID) {
        this.scheduleID = scheduleID;
    }

    public Task getTask() {
        return task;
    }

    public void setTask(Task task) {
        this.task = task;
    }

    public LocalDateTime getStartTime() {
        return startTime;
    }

    public void setStartTime(LocalDateTime startTime) {
        this.startTime = startTime;
    }

    public LocalDateTime getStopTime() {
        return stopTime;
    }

    public void setStopTime(LocalDateTime stopTime) {
        this.stopTime = stopTime;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AbstractSchedule that = (AbstractSchedule) o;
        return scheduleID == that.scheduleID && Objects.equals(task, that.task) && Objects.equals(startTime, that.startTime) && Objects.equals(stopTime, that.stopTime);
    }

    @Override
    public int hashCode() {
        return Objects.hash(scheduleID, task, startTime, stopTime);
    }
}
